unit JobLib;
interface
uses Windows,SysUtils,PresetLib;

type TID3Info=record
                Title:string[31];
                Artist:string[31];
                Album:string[31];
                Year:string[5];
                Genre:byte;
                Track:byte;
                Comment:string[31];
              end;

type TInputType=(Wave,Layer1,Layer2,Layer3,Ogg,PCM,Invalid);

type TJob=record
            SourceFile,DestFile:shortstring;
            InputType:TInputType;
            ReallyEncode:boolean;
            AddID3Tag:boolean;
            ID3Info:TID3Info;
          end;

var Jobs:array of TJob;
    EncodeSettings:TSettings;

procedure InitAddJobs(MaxJobs:integer);
procedure AddJob(const FileName:string);
procedure DoneAddJobs;

procedure EncodeAll;

function QueryJob(JobNo:integer):boolean;
function QueryAll:boolean;

implementation
uses Main,CoreLib,JobSettings;

var AddJobPos:integer;

procedure InitAddJobs(MaxJobs:integer);
begin
  SetLength(Jobs,MaxJobs);
  AddJobPos:=0;
end;

procedure AddJob(const FileName:string);
var LastDot:byte;
    Ext:string[5];
    FileType:TInputType;
begin
  if not FileExists(FileName) then exit;
  LastDot:=length(FileName);
  while (LastDot>1) AND (FileName[LastDot]<>'.') AND (FileName[LastDot]<>'\') do
    dec(LastDot);
  if FileName[LastDot]<>'.' then exit;
  Ext:=UpperCase(copy(FileName,LastDot,5));

  FileType:=Invalid;
  if Ext='.WAV' then FileType:=Wave;
  if Ext='.MP1' then FileType:=Layer1;
  if Ext='.MP2' then FileType:=Layer2;
  if Ext='.MP3' then FileType:=Layer3;
  if Ext='.OGG' then FileType:=Ogg;
  if Ext='.PCM' then FileType:=PCM;
  if Ext='.RAW' then FileType:=PCM;
  if FileType=Invalid then exit;

  with Jobs[AddJobPos] do begin
    SourceFile:=FileName;
    if FileType=Layer3
      then DestFile:=copy(FileName,1,LastDot)+'recoded.mp3'
      else DestFile:=copy(FileName,1,LastDot)+'mp3';
    InputType:=FileType;
    ReallyEncode:=true;
    AddID3Tag:=false;
    FillChar(ID3Info,sizeof(TID3Info),0);
  end;
  inc(AddJobPos);
end;

procedure DoneAddJobs;
begin
  SetLength(Jobs,AddJobPos);
end;

procedure EncodeAll;
var JobNo:integer;
begin
  for JobNo:=0 to High(Jobs) do ExecuteJob(Jobs[JobNo]);
end;

function QueryJob(JobNo:integer):boolean;
begin
  with JobForm do begin
    ImportJob(Jobs[JobNo],JobNo+1,High(Jobs)+1);
    if (ShowModal=idOK) then begin
      ExportJob(Jobs[JobNo]);
      QueryJob:=true;
    end else
      QueryJob:=false;
  end;
end;

function QueryAll:boolean;
var JobNo:integer;
begin
  QueryAll:=true;
  for JobNo:=0 to High(Jobs) do
    if not QueryJob(JobNo) then begin
      QueryAll:=false;
      exit;
    end;
end;

initialization
  SetLength(Jobs,0);
end.
